#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
#-----------------------------------------------------------------------------
Name		:	shaderc
Version		:	2024.3
Release		:	17.2.0.rel%{?dist}
Summary		:	Collection of tools, libraries, and tests for Vulkan shader compilation

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	Apache-2.0
URL		:	https://github.com/google/shaderc

Source0		:	%{name}-%{version}.tar.gz

#-----------------------------------------------------------------------------
BuildRequires	:	cmake
BuildRequires	:	gcc-c++
BuildRequires	:	glslang-devel
BuildRequires	:	ninja
BuildRequires	:	sed
BuildRequires	:	SPIRV-Headers-devel
BuildRequires	:	SPIRV-Tools-devel

#-----------------------------------------------------------------------------
%description
A collection of tools, libraries and tests for
shader compilation.
 
Shaderc aims to to provide:
 - a command line compiler with GCC- and Clang-like
   usage, for better integration with build systems
 - an API where functionality can be added without
   breaking existing clients
 - an API supporting standard concurrency patterns
   across multiple operating systems
 - increased functionality such as file #include support

#-----------------------------------------------------------------------------
%files
%defattr(-,root,root,-)

#=============================================================================
%package		-n glslc
Summary		:	A command line compiler for GLSL/HLSL to SPIR-V

#-----------------------------------------------------------------------------
%description		-n glslc
A command line compiler for GLSL/HLSL to SPIR-V.

#-----------------------------------------------------------------------------
%files			-n glslc
%defattr(-,root,root,-)
%doc glslc/README.asciidoc
%license LICENSE
%{_bindir}/glslc

#=============================================================================
%package		-n libshaderc
Summary		:	 A library for compiling shader strings into SPIR-V

#-----------------------------------------------------------------------------
%description		-n libshaderc
A library for compiling shader strings into SPIR-V.

#-----------------------------------------------------------------------------
%files			-n libshaderc
%defattr(-,root,root,-)
%doc AUTHORS CHANGES CONTRIBUTORS README.md
%license LICENSE
%{_libdir}/libshaderc_shared.so.1*

#=============================================================================
%package		-n libshaderc-devel
Summary		:	 Development files for libshaderc

#-----------------------------------------------------------------------------
Requires	:	libshaderc	= %{version}-%{release}

#-----------------------------------------------------------------------------
%description		-n libshaderc-devel
Development library for compiling shader strings into SPIR-V.

#-----------------------------------------------------------------------------
%files			-n libshaderc-devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/*.h
%{_includedir}/%{name}/shaderc.hpp
%{_libdir}/libshaderc_shared.so
%{_libdir}/pkgconfig/shaderc.pc

#=============================================================================
%package		-n libshaderc-static
Summary		:	 A library for compiling shader strings into SPIR-V (static libraries)

#-----------------------------------------------------------------------------
%description		-n libshaderc-static
A library for compiling shader strings into SPIR-V.
Static libraries for libshaderc.

#-----------------------------------------------------------------------------
%files			-n libshaderc-static
%defattr(-,root,root,-)
%license LICENSE
%{_libdir}/libshaderc.a
%{_libdir}/libshaderc_combined.a
%{_libdir}/pkgconfig/shaderc_static.pc
%{_libdir}/pkgconfig/shaderc_combined.pc
 

#=============================================================================
%prep
%setup -q
#First, allow building with system Glslang-15.0.0 and SPIRV-Tools-1.3.296.0

sed -i							\
  -e'/build-version/d'					\
  glslc/CMakeLists.txt
sed -i							\
  -e '/third_party/d'					\
  CMakeLists.txt
sed -i							\
  -e 's|SPIRV|glslang/&|'				\
  libshaderc_util/src/compiler.cc

echo '"%{version}"' > glslc/src/build-version.inc

#-----------------------------------------------------------------------------
#building application
%build

cmake							\
	-B _bld						\
	-S .						\
	-G Ninja					\
	-D CMAKE_INSTALL_PREFIX=%{_prefix}		\
	-D CMAKE_BUILD_TYPE=Release 			\
	-D SHADERC_SKIP_TESTS=ON 			\

%define _smp_mflags -j%(/usr/bin/getconf _NPROCESSORS_ONLN)
cmake							\
	--build						\
	_bld						\
	%{_smp_mflags}					\

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
%check
cmake							\
	--build _bld					\
	--target test

#-----------------------------------------------------------------------------
#installing program
%install

%{__rm} -rf %{buildroot}

DESTDIR=%{buildroot}					\
	cmake						\
	--install					\
	_bld

#-----------------------------------------------------------------------------
%changelog
